/****************************************************************************
** Meta object code from reading C++ file 'board.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kbounce-17.08.3/board.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'board.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KBounceBoard_t {
    QByteArrayData data[13];
    char stringdata0[89];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KBounceBoard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KBounceBoard_t qt_meta_stringdata_KBounceBoard = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KBounceBoard"
QT_MOC_LITERAL(1, 13, 12), // "ballsChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 5), // "balls"
QT_MOC_LITERAL(4, 33, 11), // "fillChanged"
QT_MOC_LITERAL(5, 45, 4), // "fill"
QT_MOC_LITERAL(6, 50, 8), // "wallDied"
QT_MOC_LITERAL(7, 59, 4), // "tick"
QT_MOC_LITERAL(8, 64, 12), // "wallFinished"
QT_MOC_LITERAL(9, 77, 2), // "x1"
QT_MOC_LITERAL(10, 80, 2), // "y1"
QT_MOC_LITERAL(11, 83, 2), // "x2"
QT_MOC_LITERAL(12, 86, 2) // "y2"

    },
    "KBounceBoard\0ballsChanged\0\0balls\0"
    "fillChanged\0fill\0wallDied\0tick\0"
    "wallFinished\0x1\0y1\0x2\0y2"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KBounceBoard[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       4,    1,   42,    2, 0x06 /* Public */,
       6,    0,   45,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   46,    2, 0x09 /* Protected */,
       8,    4,   47,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   11,   12,

       0        // eod
};

void KBounceBoard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KBounceBoard *_t = static_cast<KBounceBoard *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->ballsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->fillChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->wallDied(); break;
        case 3: _t->tick(); break;
        case 4: _t->wallFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KBounceBoard::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KBounceBoard::ballsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KBounceBoard::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KBounceBoard::fillChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KBounceBoard::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KBounceBoard::wallDied)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KBounceBoard::staticMetaObject = {
    { &QGraphicsObject::staticMetaObject, qt_meta_stringdata_KBounceBoard.data,
      qt_meta_data_KBounceBoard,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KBounceBoard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KBounceBoard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KBounceBoard.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsObject::qt_metacast(_clname);
}

int KBounceBoard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KBounceBoard::ballsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KBounceBoard::fillChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KBounceBoard::wallDied()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
